@@ -185,7 +185,8 @@ run_normal_job(cl_t *line, int info_fd)
         send_msg_fd(info_fd, "Job '%s' started.", line->cl_shell);
     }
     else {
-        warn_fd(info_fd, "    process already running: %s's '%s'",
+        warn_fd(info_fd,
+                "    Skipping execution of already running job: %s's '%s'",
                 line->cl_file->cf_user, line->cl_shell);
     }
 
@@ -1463,7 +1464,7 @@ set_next_exe_startup(struct cl_t *cl, const int context,
         else {
             /* job has been stopped during execution :
              * launch it again */
-            warn("Job '%s' did not finish : running it again.", cl->cl_shell);
+            warn("Job '%s' did not finish : adding it to the serial queue to run it again.", cl->cl_shell);
             set_serial_once(cl->cl_option);
             add_serial_job(cl, -1);
         }
@@ -1523,13 +1524,21 @@ set_next_exe_startup(struct cl_t *cl, const int context,
                 else {
                     /* run bootrun jobs */
                     cl->cl_remain = cl->cl_runfreq;
-                    debug("   boot-run '%s'", cl->cl_shell);
+                    debug
+                        ("   bootrun job should have run during down time '%s'",
+                         cl->cl_shell);
                     if (!is_lavg(cl->cl_option)) {
+                        explain
+                            ("   Adding bootrun job to the serial queue: '%s'",
+                             cl->cl_shell);
                         set_serial_once(cl->cl_option);
                         add_serial_job(cl, -1);
                     }
-                    else
+                    else {
+                        explain("   Adding bootrun job to the lavg queue: '%s'",
+                                cl->cl_shell);
                         add_lavg_job(cl, -1);
+                    }
                 }
                 set_next_exe(cl, STD, -1);
             }
