@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2006 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2025 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: fcronsighup.h,v 1.3 2006/01/11 00:40:46 thib Exp thib $ */
 
 #ifndef __FCRONSIGHUP_H__
 #define __FCRONSIGHUP_H__
@@ -29,4 +28,10 @@
 /* We create a .h (even if empty !)  because we have a generic rule
    in Makefile to create .o files which needs the corresponding .h to exist. */
 
-#endif /* __FCRONSIGHUP_H__ */
+#include "global.h"
+#include "mem.h"
+
+extern uid_t rootuid;
+extern gid_t rootgid;
+
+#endif                          /* __FCRONSIGHUP_H__ */
