@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2006 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2025 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,14 +21,13 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: fileconf.h,v 1.6 2006/01/11 00:53:12 thib Exp thib $ */
 
 #ifndef __FILECONF_H__
 #define __FILECONF_H__
 
 /* functions prototypes */
-extern int read_file(char *filename);
+extern int read_file(char *filename, int fd);
 extern void delete_file(const char *user_name);
 extern int save_file(char *path);
 
-#endif /* __FILECONF_H__ */
+#endif                          /* __FILECONF_H__ */
