@@ -1,7 +1,7 @@
 /*
  * FCRON - periodic command scheduler 
  *
- *  Copyright 2000-2006 Thibault Godouet <fcron@free.fr>
+ *  Copyright 2000-2025 Thibault Godouet <fcron@free.fr>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
  *  `LICENSE' that comes with the fcron source distribution.
  */
 
- /* $Id: option.h,v 1.24 2006/01/11 00:58:14 thib Exp thib $ */
 
 /* This has been inspired from bitstring(3) : here is the original copyright :
  */
@@ -52,9 +51,13 @@
 
 /* WARNING : do not change any option number, nor remove any option, nor change
  *           the meaning of a value (i.e. bit set to 1 -> true).
- *           It can lead to errors with fcrontabs save to disk/load in memory.
+ *           It can lead to errors with fcrontabs already saved to disk
+ *           or loaded in memory.
  */
 
+/* WARNING : if you add some options, make sure that OPTION_SIZE is big
+ *           enough in global.h */
+
 /*
   
   The options are :
@@ -80,13 +83,19 @@
   16     should mons field be ignored in goto_non_matching() ?
   17     should dow field be ignored in goto_non_matching() ?
   18     First freq is the freq (*ly) or the first field to take into account ?
-  19     Freq (ie daily) is from middle to middle of interval (ie nightly) ?
+  19     Freq (ie daily) is from middle to middle of period (ie nightly) ?
   20     Should we remove a %-job from lavg queue if the interval is exceeded ?
   21     Should user be mailed if a %-job has not run during a period ?
   22     Should fcron log everything about this job or just errors ?
   23     Should this job be run asap, or randomly in its allowed interval of execution ?
   24     Should first value be applied at each fcron startup, or before line first exe ?
   25     if fcron is running in foreground, print jobs output to stderr/stdout or mail ?
+  26     should the output of the job be emailed to the user only non-zero exit status ?
+  27     rebootreset: if set then apply option first at each system startup
+  28     runatreboot: if set then run the job at each system startup
+  29     runonce: if set then run the job only once
+  30     hasrun: set if the job has been run at least once
+  31     runatresume: if set then run the job at each system resume (from suspend/hibernation)
 
 */
 
@@ -358,8 +367,8 @@
 
 
 /*
-  bit 19 : set to 1 : run once from mid-interval to mid-interval (i.e. nightly)
-           set to 0 : run once from begin to the end of interval (i.e. daily)
+  bit 19 : set to 1 : run once from mid-period to mid-period (i.e. nightly)
+           set to 0 : run once from begin to the end of period (i.e. daily)
 */
 #define	is_freq_mid(opt) \
 	(_bit_test(opt, 19))
@@ -430,7 +439,7 @@
 	(_bit_clear(opt, 24))
 
 /*
-  bit 25 : set to 1 : if fcron is running in the forground, then also let jobs print
+  bit 25 : set to 1 : if fcron is running in the foreground, then also let jobs print
                       to stderr/stdout instead of mailing or discarding it
            set to 0 : if fcron is not running in the foreground or this bit is not
 	              set, then treat it as specified with the other options
@@ -442,6 +451,76 @@
 #define clear_stdout(opt) \
 	(_bit_clear(opt, 25))
 
+/*
+  bit 26 : set to 1 : The ouput of a job will only be emailed to the user if the job
+                      exited with a non-zero status.
+           set to 0 : The exit-status of the job won't be taken into account to decide
+                      if the output should be emailed to the user.
+*/
+#define	is_erroronlymail(opt) \
+	(_bit_test(opt, 26))
+#define	set_erroronlymail(opt) \
+	(_bit_set(opt, 26))
+#define clear_erroronlymail(opt) \
+	(_bit_clear(opt, 26))
 
-#endif /* __OPTIONH__ */
+/*
+  bit 27 : set to 1 : at each system startup, run the job after the delay set
+                      in the option first
+           set to 0 : leave the nextexe time as it
+*/
+#define	is_rebootreset(opt) \
+	(_bit_test(opt, 27))
+#define	set_rebootreset(opt) \
+	(_bit_set(opt, 27))
+#define clear_rebootreset(opt) \
+	(_bit_clear(opt, 27))
 
+/*
+  bit 28 : set to 1 : run the job immediately after the system startup
+           set to 0 : leave the nextexe time as it
+*/
+#define	is_runatreboot(opt) \
+	(_bit_test(opt, 28))
+#define	set_runatreboot(opt) \
+	(_bit_set(opt, 28))
+#define clear_runatreboot(opt) \
+	(_bit_clear(opt, 28))
+
+/*
+  bit 29 : set to 1 : run the job only once until next system reboot
+                      (or next fcron restart if volatile is set)
+           set to 0 : don't limit the number of times the job is run
+*/
+#define	is_runonce(opt) \
+	(_bit_test(opt, 29))
+#define	set_runonce(opt) \
+	(_bit_set(opt, 29))
+#define clear_runonce(opt) \
+	(_bit_clear(opt, 29))
+
+/*
+  bit 30 : set to 1 : the job has run at least once since system reboot
+                      (or since fcron restart if volatile is set,
+                      or since last resume if runatresume is set)
+           set to 0 : job hasn't run yet
+*/
+#define	is_hasrun(opt) \
+	(_bit_test(opt, 30))
+#define	set_hasrun(opt) \
+	(_bit_set(opt, 30))
+#define clear_hasrun(opt) \
+	(_bit_clear(opt, 30))
+
+/*
+  bit 31 : set to 1 : run the job immediately after the system resume (from suspend/hibernation)
+           set to 0 : leave the nextexe time as it
+*/
+#define	is_runatresume(opt) \
+    (_bit_test(opt, 31))
+#define	set_runatresume(opt) \
+    (_bit_set(opt, 31))
+#define clear_runatresume(opt) \
+    (_bit_clear(opt, 31))
+
+#endif                          /* __OPTIONH__ */
